@@ -1,18 +1,10 @@
 """Simple wave generator"""
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
-from .wave import (
-    IncompatibleTimeAxisRates,
-    MissingTimeAxis,
-    Noise,
-    TimeAxis,
-    Wave,
-    Wavematic,
-)
+from .wave import MissingTimeAxis, Noise, TimeAxis, Wave, Wavematic
 
 __all_exports = [
-    IncompatibleTimeAxisRates,
     MissingTimeAxis,
     Noise,
     TimeAxis,
